pub fn despawn_all<F: QueryFilter>() -> impl CommandExpand description
A Command that despawns all entities matching a specific QueryFilter.
pub fn despawn_all<F: QueryFilter>() -> impl CommandA Command that despawns all entities matching a specific QueryFilter.